==> adams-twitter-0.4.12-test-sources.jar: adams/flow/transformer/TwitterFilterTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TwitterFilterTest.java
 * Copyright (C) 2010-2014 University of Waikato, Hamilton, New Zealand
 */

package adams.flow.transformer;

import junit.framework.Test;
import junit.framework.TestSuite;
import adams.core.base.BaseString;
import adams.core.base.TwitterFilterExpression;
import adams.data.io.input.FixedTweets;
import adams.data.twitter.TextConverter;
import adams.data.twitter.TwitterField;
import adams.env.Environment;
import adams.flow.AbstractFlowTest;
import adams.flow.control.Flow;
import adams.flow.core.AbstractActor;
import adams.flow.sink.Console;
import adams.flow.source.TweetReplay;

/**
 * Tests the TwitterFilter actor.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 8617 $
 */
public class TwitterFilterTest
  extends AbstractFlowTest {

  /**
   * Initializes the test.
   *
   * @param name	the name of the test
   */
  public TwitterFilterTest(String name) {
    super(name);
  }

  /**
   * Called by JUnit before each test method.
   *
   * @throws Exception if an error occurs
   */
  @Override
  protected void setUp() throws Exception {
    super.setUp();

    m_TestHelper.deleteFileFromTmp("dumpfile.txt");
  }

  /**
   * Called by JUnit after each test method.
   *
   * @throws Exception	if tear-down fails
   */
  @Override
  protected void tearDown() throws Exception {
    m_TestHelper.deleteFileFromTmp("dumpfile.txt");

    super.tearDown();
  }

  /**
   * Used to create an instance of a specific actor.
   *
   * @return a suitably configured <code>AbstractActor</code> value
   */
  @Override
  public AbstractActor getActor() {
    TweetReplay tr = new TweetReplay();
    FixedTweets ft = new FixedTweets();
    ft.setTweets(new BaseString[]{
	new BaseString("Wassup!!!!! :("),
	new BaseString("El Duderino"),
	new BaseString("The dude abides :)"),
    });
    tr.setReplay(ft);
    
    TwitterFilter tf = new TwitterFilter();
    tf.setExpression(new TwitterFilterExpression("text:\":)\" or text:\":(\""));

    TwitterConverter tc = new TwitterConverter();
    TextConverter conv = new TextConverter();
    conv.setFields(new TwitterField[]{TwitterField.TEXT});
    tc.setConverter(conv);

    Console con = new Console();

    Flow flow = new Flow();
    flow.setActors(new AbstractActor[]{tr, tf, tc, con});

    return flow;
  }

  /**
   * Returns a test suite.
   *
   * @return		the test suite
   */
  public static Test suite() {
    return new TestSuite(TwitterFilterTest.class);
  }

  /**
   * Runs the test from commandline.
   *
   * @param args	ignored
   */
  public static void main(String[] args) {
    Environment.setEnvironmentClass(Environment.class);
    runTest(suite());
  }
}

==> adams-twitter-16.12.0-test-sources.jar: adams/flow/transformer/TwitterFilterTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TwitterFilterTest.java
 * Copyright (C) 2010-2014 University of Waikato, Hamilton, New Zealand
 */

package adams.flow.transformer;

import junit.framework.Test;
import junit.framework.TestSuite;
import adams.core.base.BaseString;
import adams.core.base.TwitterFilterExpression;
import adams.data.io.input.FixedTweets;
import adams.data.twitter.TextConverter;
import adams.data.twitter.TwitterField;
import adams.env.Environment;
import adams.flow.AbstractFlowTest;
import adams.flow.control.Flow;
import adams.flow.core.Actor;
import adams.flow.sink.Console;
import adams.flow.source.TweetReplay;

/**
 * Tests the TwitterFilter actor.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 12532 $
 */
public class TwitterFilterTest
  extends AbstractFlowTest {

  /**
   * Initializes the test.
   *
   * @param name	the name of the test
   */
  public TwitterFilterTest(String name) {
    super(name);
  }

  /**
   * Called by JUnit before each test method.
   *
   * @throws Exception if an error occurs
   */
  @Override
  protected void setUp() throws Exception {
    super.setUp();

    m_TestHelper.deleteFileFromTmp("dumpfile.txt");
  }

  /**
   * Called by JUnit after each test method.
   *
   * @throws Exception	if tear-down fails
   */
  @Override
  protected void tearDown() throws Exception {
    m_TestHelper.deleteFileFromTmp("dumpfile.txt");

    super.tearDown();
  }

  /**
   * Used to create an instance of a specific actor.
   *
   * @return a suitably configured <code>Actor</code> value
   */
  @Override
  public Actor getActor() {
    TweetReplay tr = new TweetReplay();
    FixedTweets ft = new FixedTweets();
    ft.setTweets(new BaseString[]{
	new BaseString("Wassup!!!!! :("),
	new BaseString("El Duderino"),
	new BaseString("The dude abides :)"),
    });
    tr.setReplay(ft);
    
    TwitterFilter tf = new TwitterFilter();
    tf.setExpression(new TwitterFilterExpression("text:\":)\" or text:\":(\""));

    TwitterConverter tc = new TwitterConverter();
    TextConverter conv = new TextConverter();
    conv.setFields(new TwitterField[]{TwitterField.TEXT});
    tc.setConverter(conv);

    Console con = new Console();

    Flow flow = new Flow();
    flow.setActors(new Actor[]{tr, tf, tc, con});

    return flow;
  }

  /**
   * Returns a test suite.
   *
   * @return		the test suite
   */
  public static Test suite() {
    return new TestSuite(TwitterFilterTest.class);
  }

  /**
   * Runs the test from commandline.
   *
   * @param args	ignored
   */
  public static void main(String[] args) {
    Environment.setEnvironmentClass(Environment.class);
    runTest(suite());
  }
}
